==> ejc-zjkjcost-impl-3.0.0-20230420.120951-140-sources.jar: com/ejianc/business/zjkjcost/optimization/bean/OptimizationRewardEntity.java <==
package com.ejianc.business.zjkjcost.optimization.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 项目优化-项目优化奖励申请
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_optimization_reward")
public class OptimizationRewardEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="topic_id")
    private Long topicId; // 项目优化立项申报id
    @TableField(value="topic_name")
    private String topicName; // 项目优化立项申报名称
    @TableField(value="topic_code")
    private String topicCode; // 项目优化立项申报编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 实现净效益额
    @TableField(value="reward_mny")
    private BigDecimal rewardMny; // 按项目优化奖标准应计取奖励金额
    @TableField(value="benefit_explain")
    private String benefitExplain; // 实现净效益额详情
    @TableField(value="reward_explain")
    private String rewardExplain; // 按项目优化奖标准应计取奖励金额详情
    @TableField(value="sign_status")
    private Integer signStatus; // 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
    @TableField(value="review_opinion")
    private String reviewOpinion; // 评审意见
    @TableField(value="department_benefit_mny")
    private BigDecimal departmentBenefitMny; // 所属单位商务管理部实现净效益额
    @TableField(value="department_reward_mny")
    private BigDecimal departmentRewardMny; // 所属单位商务管理部按项目优化奖标准应计取奖励金额
    @TableField(value="department_benefit_explain")
    private String departmentBenefitExplain; // 所属单位商务管理部实现净效益额详情
    @TableField(value="department_reward_explain")
    private String departmentRewardExplain; // 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
    @TableField(value="leader_reward_mny")
    private BigDecimal leaderRewardMny; // 所属单位分管领导计取奖励金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申请金额

    @TableField(value="topic_type_id")
    private Long topicTypeId;
    @TableField(value="topic_type_name")
    private String topicTypeName;


    @TableField(value="calc_id")
    private Long calcId; // 项目优化立项计算id
    @TableField(value="calc_name")
    private String calcName; // 项目优化立项计算名称
    @TableField(value="calc_code")
    private String calcCode; // 项目优化立项计算编号

    public Long getCalcId() {
        return calcId;
    }

    public void setCalcId(Long calcId) {
        this.calcId = calcId;
    }

    public String getCalcName() {
        return calcName;
    }

    public void setCalcName(String calcName) {
        this.calcName = calcName;
    }

    public String getCalcCode() {
        return calcCode;
    }

    public void setCalcCode(String calcCode) {
        this.calcCode = calcCode;
    }

    public Long getTopicTypeId() {
        return topicTypeId;
    }

    public void setTopicTypeId(Long topicTypeId) {
        this.topicTypeId = topicTypeId;
    }

    public String getTopicTypeName() {
        return topicTypeName;
    }

    public void setTopicTypeName(String topicTypeName) {
        this.topicTypeName = topicTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getTopicId() {
        return topicId;
    }

    public void setTopicId(Long topicId) {
        this.topicId = topicId;
    }
    public String getTopicName() {
        return topicName;
    }

    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }
    public String getTopicCode() {
        return topicCode;
    }

    public void setTopicCode(String topicCode) {
        this.topicCode = topicCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getRewardMny() {
        return rewardMny;
    }

    public void setRewardMny(BigDecimal rewardMny) {
        this.rewardMny = rewardMny;
    }
    public String getBenefitExplain() {
        return benefitExplain;
    }

    public void setBenefitExplain(String benefitExplain) {
        this.benefitExplain = benefitExplain;
    }
    public String getRewardExplain() {
        return rewardExplain;
    }

    public void setRewardExplain(String rewardExplain) {
        this.rewardExplain = rewardExplain;
    }
    public Integer getSignStatus() {
        return signStatus;
    }

    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }
    public String getReviewOpinion() {
        return reviewOpinion;
    }

    public void setReviewOpinion(String reviewOpinion) {
        this.reviewOpinion = reviewOpinion;
    }
    public BigDecimal getDepartmentBenefitMny() {
        return departmentBenefitMny;
    }

    public void setDepartmentBenefitMny(BigDecimal departmentBenefitMny) {
        this.departmentBenefitMny = departmentBenefitMny;
    }
    public BigDecimal getDepartmentRewardMny() {
        return departmentRewardMny;
    }

    public void setDepartmentRewardMny(BigDecimal departmentRewardMny) {
        this.departmentRewardMny = departmentRewardMny;
    }
    public String getDepartmentBenefitExplain() {
        return departmentBenefitExplain;
    }

    public void setDepartmentBenefitExplain(String departmentBenefitExplain) {
        this.departmentBenefitExplain = departmentBenefitExplain;
    }
    public String getDepartmentRewardExplain() {
        return departmentRewardExplain;
    }

    public void setDepartmentRewardExplain(String departmentRewardExplain) {
        this.departmentRewardExplain = departmentRewardExplain;
    }
    public BigDecimal getLeaderRewardMny() {
        return leaderRewardMny;
    }

    public void setLeaderRewardMny(BigDecimal leaderRewardMny) {
        this.leaderRewardMny = leaderRewardMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }

    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
}

==> ejc-zjkjcost-impl-3.0.0-20230512.081102-161-sources.jar: com/ejianc/business/zjkjcost/optimization/bean/OptimizationRewardEntity.java <==
package com.ejianc.business.zjkjcost.optimization.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 项目优化-项目优化奖励申请
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_optimization_reward")
public class OptimizationRewardEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="topic_id")
    private Long topicId; // 项目优化立项申报id
    @TableField(value="topic_name")
    private String topicName; // 项目优化立项申报名称
    @TableField(value="topic_code")
    private String topicCode; // 项目优化立项申报编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 实现净效益额
    @TableField(value="reward_mny")
    private BigDecimal rewardMny; // 按项目优化奖标准应计取奖励金额
    @TableField(value="benefit_explain")
    private String benefitExplain; // 实现净效益额详情
    @TableField(value="reward_explain")
    private String rewardExplain; // 按项目优化奖标准应计取奖励金额详情
    @TableField(value="sign_status")
    private Integer signStatus; // 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
    @TableField(value="review_opinion")
    private String reviewOpinion; // 评审意见
    @TableField(value="department_benefit_mny")
    private BigDecimal departmentBenefitMny; // 所属单位商务管理部实现净效益额
    @TableField(value="department_reward_mny")
    private BigDecimal departmentRewardMny; // 所属单位商务管理部按项目优化奖标准应计取奖励金额
    @TableField(value="department_benefit_explain")
    private String departmentBenefitExplain; // 所属单位商务管理部实现净效益额详情
    @TableField(value="department_reward_explain")
    private String departmentRewardExplain; // 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
    @TableField(value="leader_reward_mny")
    private BigDecimal leaderRewardMny; // 所属单位分管领导计取奖励金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申请金额

    @TableField(value="topic_type_id")
    private Long topicTypeId;
    @TableField(value="topic_type_name")
    private String topicTypeName;


    @TableField(value="calc_id")
    private Long calcId; // 项目优化立项计算id
    @TableField(value="calc_name")
    private String calcName; // 项目优化立项计算名称
    @TableField(value="calc_code")
    private String calcCode; // 项目优化立项计算编号
    @TableField(value="project_status")
    private String projectStatus;  // 项目状态：1-未开工, 2-在建，3-完工，4-停缓建， 5-竣工未结算， 6-竣工已结算

    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }

    public Long getCalcId() {
        return calcId;
    }

    public void setCalcId(Long calcId) {
        this.calcId = calcId;
    }

    public String getCalcName() {
        return calcName;
    }

    public void setCalcName(String calcName) {
        this.calcName = calcName;
    }

    public String getCalcCode() {
        return calcCode;
    }

    public void setCalcCode(String calcCode) {
        this.calcCode = calcCode;
    }

    public Long getTopicTypeId() {
        return topicTypeId;
    }

    public void setTopicTypeId(Long topicTypeId) {
        this.topicTypeId = topicTypeId;
    }

    public String getTopicTypeName() {
        return topicTypeName;
    }

    public void setTopicTypeName(String topicTypeName) {
        this.topicTypeName = topicTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getTopicId() {
        return topicId;
    }

    public void setTopicId(Long topicId) {
        this.topicId = topicId;
    }
    public String getTopicName() {
        return topicName;
    }

    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }
    public String getTopicCode() {
        return topicCode;
    }

    public void setTopicCode(String topicCode) {
        this.topicCode = topicCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getRewardMny() {
        return rewardMny;
    }

    public void setRewardMny(BigDecimal rewardMny) {
        this.rewardMny = rewardMny;
    }
    public String getBenefitExplain() {
        return benefitExplain;
    }

    public void setBenefitExplain(String benefitExplain) {
        this.benefitExplain = benefitExplain;
    }
    public String getRewardExplain() {
        return rewardExplain;
    }

    public void setRewardExplain(String rewardExplain) {
        this.rewardExplain = rewardExplain;
    }
    public Integer getSignStatus() {
        return signStatus;
    }

    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }
    public String getReviewOpinion() {
        return reviewOpinion;
    }

    public void setReviewOpinion(String reviewOpinion) {
        this.reviewOpinion = reviewOpinion;
    }
    public BigDecimal getDepartmentBenefitMny() {
        return departmentBenefitMny;
    }

    public void setDepartmentBenefitMny(BigDecimal departmentBenefitMny) {
        this.departmentBenefitMny = departmentBenefitMny;
    }
    public BigDecimal getDepartmentRewardMny() {
        return departmentRewardMny;
    }

    public void setDepartmentRewardMny(BigDecimal departmentRewardMny) {
        this.departmentRewardMny = departmentRewardMny;
    }
    public String getDepartmentBenefitExplain() {
        return departmentBenefitExplain;
    }

    public void setDepartmentBenefitExplain(String departmentBenefitExplain) {
        this.departmentBenefitExplain = departmentBenefitExplain;
    }
    public String getDepartmentRewardExplain() {
        return departmentRewardExplain;
    }

    public void setDepartmentRewardExplain(String departmentRewardExplain) {
        this.departmentRewardExplain = departmentRewardExplain;
    }
    public BigDecimal getLeaderRewardMny() {
        return leaderRewardMny;
    }

    public void setLeaderRewardMny(BigDecimal leaderRewardMny) {
        this.leaderRewardMny = leaderRewardMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }

    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
}
